==> custom_pages-v1.12.9.zip: custom_pages/messages/am/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => ' {templateName} <strong>አክል</stron>',
    '<strong>Custom</strong> Pages' => '<strong>ብጁ</strong> ገፃቹ',
    '<strong>Edit</strong> snippet' => 'ቁንፅል መረጃውን <strong>አስተካክል</strong>',
    'Add' => 'አክል',
    'Add a file icon before the title' => 'ከርዕሱ በፊት ለፋይሉ መለያ ምስል ያክሉ',
    'Adds plain HTML content to your site.' => 'ለደረገፅዎ ግልፅ የHTML ይዘት ያክሉ።',
    'Advanced' => 'የላቀ',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'በመወያያው የማውጫ ቁልፎች (ዝርዝርማምረጫ፣ iframe ወይም ማስፈንጠሪያ) ገፃች ለማክል ይፈቀዳል',
    'Allows you to add content in MarkDown syntax.' => 'በዝርዝር መምረጫው ማስፈሪያ ላይ ይዘት ለማስገባት ይፈቀድልዎታል',
    'Alternate text' => 'አማራጭ ፅሁፍ',
    'Always make a backup of your view files outside of your production environment!' => 'ሁልጊዜም ከሚያከናውኑበት ቦታ ውጪ የመጠባበቂያ ፋይል ያዘጋጁ።',
    'An empty allowed template selection will allow all container templates for this container.' => 'የተፈቀደ ባዶ የአብነት ምርጫ ሁሉም ማዕቀፎች በዚህ ማዕቀፍ ላይ ተግባራዊ እንዲሆኑ ይፈቅዳል።',
    'Back' => 'ተመለስ',
    'Back to dashboard' => 'ወደመከወኛ ሰሌዳው ተመለስ',
    'Back to overview' => 'ወደሐተታው ተመለስ',
    'Back to space' => 'ወደመወያያው ተመለስ',
    'Configuration' => 'ውቅር',
    'Content' => 'ይዘት',
    'Css Class' => 'የccs ክፍል',
    'Custom Pages' => 'ብጁ ገፅ',
    'Custom pages' => 'ብጁ ጋፃች',
    'Dashboard' => 'መከወኛ ሰሌዳ',
    'Default' => 'ነባሪ',
    'Default Content' => 'ነባሪ ይዘት',
    'Delete' => 'አስወግድ',
    'Edit' => 'ማስተካከያ',
    'Edit Page' => 'ማስተካከያ ገፅ',
    'Empty' => 'ባዶ',
    'File' => 'ፋይል',
    'General' => 'አጠቃላይ',
    'Html' => 'html',
    'ID' => 'መታወቂያ',
    'Icon' => 'አርማ',
    'Iframe' => 'Iframe',
    'Insert' => 'አስገባ',
    'Invalid request data!' => 'የማያገለግል የመረጃ ጥያቄ ቀርቧል!',
    'Invalid template selection!' => 'የአማያገለግል አብነት መርጠዋል!',
    'Invalid type selection' => 'የማያገለግል አይነት ምርጫ',
    'Invalid view file selection!' => 'የማያገለግል የፋይል መመልከቻ መርጠዋል!',
    'Link' => 'ማስፈንጠሪያ',
    'MarkDown' => 'የተመረጠዝርዝር',
    'Navigation' => 'የማውጫ ቁልፍ',
    'On this page you can configure general settings of your custom pages.' => 'በዚህ ገፅ ላይ የብጁ ገፅዎችዎን አጠቃላይ ማስተካከያዎችን ማዋቀር ይችላሉ።',
    'Overview' => 'ሐተታ',
    'PHP' => 'PHP',
    'Pages' => 'ገፃች',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'እባክዎን መሰረታቸውን PHP ያደረጉ ገፃች በተለይም የተጠቃሚዎችን ግብአት በመቆጣጠሩ በኩል ለደህንነት ችግር የተጋለጡ ናቸው። ለተጨማሪ መረጃ እባክዎን <a href="{url}">የYiiን የተመረጡ የደህንነት ተግባራትን </a> ይመልከቱ።',
    'Public' => 'የህዝብ',
    'Reset' => 'እንደገና ጀምር',
    'Settings' => 'አስተካክል',
    'Show additional file information (size)' => 'ተጨማሪ የፋይል መረጃዎችን አሳይ (መጠን)',
    'Snippets' => 'ቁንፅል መረጃዎች',
    'Sort Order' => 'ቅደም ተከተል ያስይዙ',
    'Source' => 'ምንጭ',
    'Spaces' => 'ምህዳሮች',
    'Style' => 'ቅጥ',
    'Style Class' => 'የቅጥ ክፍል',
    'Submit' => 'አቅርብ',
    'Target Url' => 'የታለመ url',
    'Template' => 'አብነት ',
    'Template Layout' => 'የአብነት አቀማመጥ',
    'Templates' => 'አብነቶሽ',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'አብነቶች አግባብ ከሆነ የማስተካከያ ትግበራ ጋር የሚዋሃዱ የገፅ ስብጥሮችን እንዲወስኑ ያደርጉዎታል።',
    'This container does not allow any further items!' => 'ይህ ማዕቀፍ ሌላ ተጨማሪ ነገር ማከል አይፈቅድም!',
    'Title' => 'ርዕስ',
    'Top Navigation' => 'የራስጌ የማውጫ ቁልፍ',
    'Topics' => 'አርዕስት',
    'Type' => 'አይነት',
    'Upload image' => 'ምስል አክል',
    'User Account Menu (Settings)' => 'የተጠቃሚ አካውንት ማውጫ (ማስተካከያ)',
    'Visibility' => 'የእይታ ሁኔታ',
    'Will embed the result of a given url as an iframe element.' => 'የቀረበው url እንደiframe አካል ሆኖ የሚቀናጅ ይሆናል።',
    'Will redirect requests to a given (relative or absolute) url.' => 'የቀረቡት ጥያቆዎች ወደ(አማራጭ ወይም ትክክለኛ) url የሚዛወሩ ይሆናል።',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'መሰረታቸውን PHP ባደረጉ ገፃች በፋይል መሰደሪያዎ ላይ ፋይሉን በመመልከት ብጁ ገፃችን መፍጠር ይችላሉ። ለተጨማሪ መረጃ እባክዎን የሞዱሌ ማዋቀሪያውን ይመልከቱ።',
    'Without adding to navigation (Direct link)' => 'ወደማውጫ ቁልፉ ሳያስገቡ (ቀጥተኛ ማስፈንጠሪያ)',
    'You are not allowed to delete default content!' => 'ነባሪ ይዘቶችን ለማስወገድ አልተፈቀደልዎትም።',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Always' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Custom' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Snippet' => '',
    'Space' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/am/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => ' {templateName} <strong>አክል</stron>',
    '<strong>Custom</strong> Pages' => '<strong>ብጁ</strong> ገፃቹ',
    '<strong>Edit</strong> snippet' => 'ቁንፅል መረጃውን <strong>አስተካክል</strong>',
    'Add' => 'አክል',
    'Add a file icon before the title' => 'ከርዕሱ በፊት ለፋይሉ መለያ ምስል ያክሉ',
    'Adds plain HTML content to your site.' => 'ለደረገፅዎ ግልፅ የHTML ይዘት ያክሉ።',
    'Advanced' => 'የላቀ',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'በመወያያው የማውጫ ቁልፎች (ዝርዝርማምረጫ፣ iframe ወይም ማስፈንጠሪያ) ገፃች ለማክል ይፈቀዳል',
    'Allows you to add content in MarkDown syntax.' => 'በዝርዝር መምረጫው ማስፈሪያ ላይ ይዘት ለማስገባት ይፈቀድልዎታል',
    'Alternate text' => 'አማራጭ ፅሁፍ',
    'Always make a backup of your view files outside of your production environment!' => 'ሁልጊዜም ከሚያከናውኑበት ቦታ ውጪ የመጠባበቂያ ፋይል ያዘጋጁ።',
    'An empty allowed template selection will allow all container templates for this container.' => 'የተፈቀደ ባዶ የአብነት ምርጫ ሁሉም ማዕቀፎች በዚህ ማዕቀፍ ላይ ተግባራዊ እንዲሆኑ ይፈቅዳል።',
    'Back' => 'ተመለስ',
    'Back to dashboard' => 'ወደመከወኛ ሰሌዳው ተመለስ',
    'Back to overview' => 'ወደሐተታው ተመለስ',
    'Back to space' => 'ወደመወያያው ተመለስ',
    'Configuration' => 'ውቅር',
    'Content' => 'ይዘት',
    'Css Class' => 'የccs ክፍል',
    'Custom Pages' => 'ብጁ ገፅ',
    'Custom pages' => 'ብጁ ጋፃች',
    'Dashboard' => 'መከወኛ ሰሌዳ',
    'Default' => 'ነባሪ',
    'Default Content' => 'ነባሪ ይዘት',
    'Delete' => 'አስወግድ',
    'Edit' => 'ማስተካከያ',
    'Edit Page' => 'ማስተካከያ ገፅ',
    'Empty' => 'ባዶ',
    'File' => 'ፋይል',
    'General' => 'አጠቃላይ',
    'Html' => 'html',
    'ID' => 'መታወቂያ',
    'Icon' => 'አርማ',
    'Iframe' => 'Iframe',
    'Insert' => 'አስገባ',
    'Invalid request data!' => 'የማያገለግል የመረጃ ጥያቄ ቀርቧል!',
    'Invalid template selection!' => 'የአማያገለግል አብነት መርጠዋል!',
    'Invalid type selection' => 'የማያገለግል አይነት ምርጫ',
    'Invalid view file selection!' => 'የማያገለግል የፋይል መመልከቻ መርጠዋል!',
    'Link' => 'ማስፈንጠሪያ',
    'MarkDown' => 'የተመረጠዝርዝር',
    'Navigation' => 'የማውጫ ቁልፍ',
    'On this page you can configure general settings of your custom pages.' => 'በዚህ ገፅ ላይ የብጁ ገፅዎችዎን አጠቃላይ ማስተካከያዎችን ማዋቀር ይችላሉ።',
    'Overview' => 'ሐተታ',
    'PHP' => 'PHP',
    'Pages' => 'ገፃች',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'እባክዎን መሰረታቸውን PHP ያደረጉ ገፃች በተለይም የተጠቃሚዎችን ግብአት በመቆጣጠሩ በኩል ለደህንነት ችግር የተጋለጡ ናቸው። ለተጨማሪ መረጃ እባክዎን <a href="{url}">የYiiን የተመረጡ የደህንነት ተግባራትን </a> ይመልከቱ።',
    'Public' => 'የህዝብ',
    'Reset' => 'እንደገና ጀምር',
    'Settings' => 'አስተካክል',
    'Show additional file information (size)' => 'ተጨማሪ የፋይል መረጃዎችን አሳይ (መጠን)',
    'Snippets' => 'ቁንፅል መረጃዎች',
    'Sort Order' => 'ቅደም ተከተል ያስይዙ',
    'Source' => 'ምንጭ',
    'Spaces' => 'ምህዳሮች',
    'Style' => 'ቅጥ',
    'Style Class' => 'የቅጥ ክፍል',
    'Submit' => 'አቅርብ',
    'Target Url' => 'የታለመ url',
    'Template' => 'አብነት ',
    'Template Layout' => 'የአብነት አቀማመጥ',
    'Templates' => 'አብነቶሽ',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'አብነቶች አግባብ ከሆነ የማስተካከያ ትግበራ ጋር የሚዋሃዱ የገፅ ስብጥሮችን እንዲወስኑ ያደርጉዎታል።',
    'This container does not allow any further items!' => 'ይህ ማዕቀፍ ሌላ ተጨማሪ ነገር ማከል አይፈቅድም!',
    'Title' => 'ርዕስ',
    'Top Navigation' => 'የራስጌ የማውጫ ቁልፍ',
    'Topics' => 'አርዕስት',
    'Type' => 'አይነት',
    'Upload image' => 'ምስል አክል',
    'User Account Menu (Settings)' => 'የተጠቃሚ አካውንት ማውጫ (ማስተካከያ)',
    'Visibility' => 'የእይታ ሁኔታ',
    'Will embed the result of a given url as an iframe element.' => 'የቀረበው url እንደiframe አካል ሆኖ የሚቀናጅ ይሆናል።',
    'Will redirect requests to a given (relative or absolute) url.' => 'የቀረቡት ጥያቆዎች ወደ(አማራጭ ወይም ትክክለኛ) url የሚዛወሩ ይሆናል።',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'መሰረታቸውን PHP ባደረጉ ገፃች በፋይል መሰደሪያዎ ላይ ፋይሉን በመመልከት ብጁ ገፃችን መፍጠር ይችላሉ። ለተጨማሪ መረጃ እባክዎን የሞዱሌ ማዋቀሪያውን ይመልከቱ።',
    'Without adding to navigation (Direct link)' => 'ወደማውጫ ቁልፉ ሳያስገቡ (ቀጥተኛ ማስፈንጠሪያ)',
    'You are not allowed to delete default content!' => 'ነባሪ ይዘቶችን ለማስወገድ አልተፈቀደልዎትም።',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Custom' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Snippet' => '',
    'Sorting' => '',
    'Space' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
